@@ -22,21 +22,24 @@
 ## image plot
 
 ## NOTE Matrix coerces to dgTMatrix and then uses levelplot
+## FIXME: Matrix does not correctly pass on labels from ngCMatrix so
+## 		we manually coerce to dgTMatrix
 setMethod("image", signature(x = "itemMatrix"),
     function(x, xlab = "Items (Columns)", ylab = "Elements (Rows)", ...) 
-    image(t(x@data), sub = NULL, ylab = ylab, xlab = xlab, ...)
+    Matrix::image(as(t(as(x, "ngCMatrix")), "dgCMatrix"), 
+	sub = NULL, ylab = ylab, xlab = xlab, ...)
 )
 
 setMethod("image", signature(x = "transactions"),
-    function(x, ...)
-    image(as(x, "itemMatrix"), xlab = "Items (Columns)", 
-        ylab = "Transactions (Rows)", ...)
+    function(x, xlab = "Items (Columns)", ylab = "Transactions (Rows)" ,...)
+    Matrix::image(as(t(as(x, "ngCMatrix")), "dgCMatrix"), 
+	sub = NULL, ylab = ylab, xlab = xlab, ...)
 )
 
 setMethod("image", signature(x = "tidLists"),
     function(x, xlab="Transactions (Columns)",
         ylab="Items/itemsets (Rows)", ...)
-        image(t(x@data), sub = NULL, colorkey = FALSE, 
+    Matrix::image(as(t(as(x, "ngCMatrix")), "dgCMatrix"), 
             ylab = ylab, xlab = xlab, ...)
 )
 
